/* Generated by wayland-scanner 1.23.1 */

#ifndef QT_KEY_UNSTABLE_V1_SERVER_PROTOCOL_H
#define QT_KEY_UNSTABLE_V1_SERVER_PROTOCOL_H

#include <stdint.h>
#include <stddef.h>
#include "wayland-server-core.h"

#ifdef  __cplusplus
extern "C" {
#endif

struct wl_client;
struct wl_resource;

/**
 * @page page_qt_key_unstable_v1 The qt_key_unstable_v1 protocol
 * @section page_ifaces_qt_key_unstable_v1 Interfaces
 * - @subpage page_iface_zqt_key_v1 - send serialized QKeyEvents
 * @section page_copyright_qt_key_unstable_v1 Copyright
 * <pre>
 *
 * Copyright (C) 2018 The Qt Company Ltd.
 * SPDX-License-Identifier: LicenseRef-Qt-Commercial OR BSD-3-Clause
 * </pre>
 */
struct wl_surface;
struct zqt_key_v1;

#ifndef ZQT_KEY_V1_INTERFACE
#define ZQT_KEY_V1_INTERFACE
/**
 * @page page_iface_zqt_key_v1 zqt_key_v1
 * @section page_iface_zqt_key_v1_desc Description
 *
 * This protocol is independent of the Wayland seat concept. Its
 * intention is to let a QKeyEvent be transferred from a Qt compositor
 * to a Qt client without losing or adding false information by going
 * through wl_seat and wl_keyboard.
 *
 * Note: This protocol is considered private to Qt. We will do our
 * best to bump version numbers when we make backwards compatible
 * changes, bump the protocol name and interface suffixes when we make
 * backwards incompatible changes, but we provide no guarantees. We
 * may also remove the protocol without warning. Implement this at
 * your own risk.
 * @section page_iface_zqt_key_v1_api API
 * See @ref iface_zqt_key_v1.
 */
/**
 * @defgroup iface_zqt_key_v1 The zqt_key_v1 interface
 *
 * This protocol is independent of the Wayland seat concept. Its
 * intention is to let a QKeyEvent be transferred from a Qt compositor
 * to a Qt client without losing or adding false information by going
 * through wl_seat and wl_keyboard.
 *
 * Note: This protocol is considered private to Qt. We will do our
 * best to bump version numbers when we make backwards compatible
 * changes, bump the protocol name and interface suffixes when we make
 * backwards incompatible changes, but we provide no guarantees. We
 * may also remove the protocol without warning. Implement this at
 * your own risk.
 */
extern const struct wl_interface zqt_key_v1_interface;
#endif

#define ZQT_KEY_V1_KEY 0

/**
 * @ingroup iface_zqt_key_v1
 */
#define ZQT_KEY_V1_KEY_SINCE_VERSION 1


/**
 * @ingroup iface_zqt_key_v1
 * Sends an key event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
zqt_key_v1_send_key(struct wl_resource *resource_, struct wl_resource *surface, uint32_t time, uint32_t type, uint32_t key, uint32_t modifiers, uint32_t nativeScanCode, uint32_t nativeVirtualKey, uint32_t nativeModifiers, const char *text, uint32_t autorepeat, uint32_t count)
{
	wl_resource_post_event(resource_, ZQT_KEY_V1_KEY, surface, time, type, key, modifiers, nativeScanCode, nativeVirtualKey, nativeModifiers, text, autorepeat, count);
}

#ifdef  __cplusplus
}
#endif

#endif
