// This file was generated by qtwaylandscanner
// source file is appmenu.xml

#ifndef QT_WAYLAND_APPMENU
#define QT_WAYLAND_APPMENU

#include <QtWaylandClient/private/wayland-appmenu-client-protocol.h>
#include <QByteArray>
#include <QString>

struct wl_registry;

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")
#if !defined(Q_WAYLAND_CLIENT_APPMENU_EXPORT)
#  if defined(QT_SHARED) && !defined(QT_STATIC)
#    if defined(QT_BUILD_WAYLANDCLIENT_LIB)
#      define Q_WAYLAND_CLIENT_APPMENU_EXPORT Q_DECL_EXPORT
#    else
#      define Q_WAYLAND_CLIENT_APPMENU_EXPORT Q_DECL_IMPORT
#    endif
#  else
#    define Q_WAYLAND_CLIENT_APPMENU_EXPORT
#  endif
#endif

namespace QtWayland {
    class Q_WAYLAND_CLIENT_APPMENU_EXPORT org_kde_kwin_appmenu_manager
    {
    public:
        org_kde_kwin_appmenu_manager(struct ::wl_registry *registry, uint32_t id, int version);
        org_kde_kwin_appmenu_manager(struct ::org_kde_kwin_appmenu_manager *object);
        org_kde_kwin_appmenu_manager();

        virtual ~org_kde_kwin_appmenu_manager();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::org_kde_kwin_appmenu_manager *object);

        struct ::org_kde_kwin_appmenu_manager *object() { return m_org_kde_kwin_appmenu_manager; }
        const struct ::org_kde_kwin_appmenu_manager *object() const { return m_org_kde_kwin_appmenu_manager; }
        static org_kde_kwin_appmenu_manager *fromObject(struct ::org_kde_kwin_appmenu_manager *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        struct ::org_kde_kwin_appmenu *create(struct ::wl_surface *surface);

    private:
        struct ::org_kde_kwin_appmenu_manager *m_org_kde_kwin_appmenu_manager;
    };

    class Q_WAYLAND_CLIENT_APPMENU_EXPORT org_kde_kwin_appmenu
    {
    public:
        org_kde_kwin_appmenu(struct ::wl_registry *registry, uint32_t id, int version);
        org_kde_kwin_appmenu(struct ::org_kde_kwin_appmenu *object);
        org_kde_kwin_appmenu();

        virtual ~org_kde_kwin_appmenu();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::org_kde_kwin_appmenu *object);

        struct ::org_kde_kwin_appmenu *object() { return m_org_kde_kwin_appmenu; }
        const struct ::org_kde_kwin_appmenu *object() const { return m_org_kde_kwin_appmenu; }
        static org_kde_kwin_appmenu *fromObject(struct ::org_kde_kwin_appmenu *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        void set_address(const QString &service_name, const QString &object_path);
        void release();

    private:
        struct ::org_kde_kwin_appmenu *m_org_kde_kwin_appmenu;
    };
}

QT_WARNING_POP
QT_END_NAMESPACE

#endif
