#define QT_FEATURE_wayland_client_primary_selection 1

#define QT_FEATURE_wayland_client_fullscreen_shell_v1 1

#define QT_FEATURE_wayland_client_ivi_shell 1

#define QT_FEATURE_wayland_client_wl_shell 1

#define QT_FEATURE_wayland_client_xdg_shell 1

#define QT_FEATURE_wayland_client_qt_shell 1

#define QT_FEATURE_egl_extension_platform_wayland 1

