// Copyright (C) 2016 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only


//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#ifndef QWAYLANDEGLINCLUDE_H
#define QWAYLANDEGLINCLUDE_H

#include <string.h>
#include <wayland-client-core.h>

#include <wayland-egl.h>

#define EGL_EGLEXT_PROTOTYPES
#include <QtGui/private/qt_egl_p.h>

#endif // QWAYLANDEGLINCLUDE_H
