/* This file was generated by syncqt. */
#ifndef QT_QTWAYLANDGLOBAL_VERSION_H
#define QT_QTWAYLANDGLOBAL_VERSION_H

#define QTWAYLANDGLOBAL_VERSION_STR "6.9.1"

#define QTWAYLANDGLOBAL_VERSION 0x060901

#endif // QT_QTWAYLANDGLOBAL_VERSION_H
