// Copyright (C) 2016 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#ifndef QWAYLANDCLIENTGLOBAL_H
#define QWAYLANDCLIENTGLOBAL_H

#include <QtGui/qtguiglobal.h>
#include <QtWaylandClient/qtwaylandclient-config.h>
#include <QtWaylandClient/qtwaylandclientexports.h>

QT_BEGIN_NAMESPACE

QT_END_NAMESPACE

#endif //QWAYLANDCLIENTGLOBAL_H

