/* This file was generated by syncqt. */
#ifndef QT_QTWAYLANDCOMPOSITORPRESENTATIONTIME_VERSION_H
#define QT_QTWAYLANDCOMPOSITORPRESENTATIONTIME_VERSION_H

#define QTWAYLANDCOMPOSITORPRESENTATIONTIME_VERSION_STR "6.9.1"

#define QTWAYLANDCOMPOSITORPRESENTATIONTIME_VERSION 0x060901

#endif // QT_QTWAYLANDCOMPOSITORPRESENTATIONTIME_VERSION_H
